/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/

package backends

import (
	"net/url"
	"strings"

	"github.com/spf13/viper"
	"go.uploadedlobster.com/scotty/internal/auth"
	"go.uploadedlobster.com/scotty/internal/models"
	"go.uploadedlobster.com/scotty/internal/storage"
)

func BuildRedirectURL(config *viper.Viper, backend string) (*url.URL, error) {
	callbackHost, _ := strings.CutSuffix(config.GetString("oauth-host"), "/")
	if callbackHost == "" {
		callbackHost = "127.0.0.1:2369"
	}
	callbackPath := "/callback/" + backend
	return url.Parse("http://" + callbackHost + callbackPath)
}

func Authenticate(service string, backend models.Backend, db storage.Database, config *viper.Viper) (bool, error) {
	authenticator, needAuth := backend.(auth.OAuth2Authenticator)
	if needAuth {
		redirectURL, err := BuildRedirectURL(config, backend.Name())
		if err != nil {
			return needAuth, err
		}
		token, err := db.GetOAuth2Token(service)
		if err != nil {
			return needAuth, err
		}
		conf := authenticator.OAuth2Strategy(redirectURL).Config()
		tokenSource := auth.NewDatabaseTokenSource(db, service, &conf, token)
		err = authenticator.OAuth2Setup(tokenSource)
		if err != nil {
			return needAuth, err
		}
	}
	return needAuth, nil
}
