/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/

package backends_test

import (
	"testing"

	"github.com/spf13/viper"
	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"go.uploadedlobster.com/scotty/internal/backends"
)

func TestBuildRedirectURL(t *testing.T) {
	config := viper.New()
	config.Set("oauth-host", "localhost:1234/")
	url, err := backends.BuildRedirectURL(config, "foo")
	require.NoError(t, err)
	assert.Equal(t, "localhost:1234", url.Host)
	assert.Equal(t, "/callback/foo", url.Path)
}

func TestBuildRedirectURLDefaultHost(t *testing.T) {
	config := viper.New()
	url, err := backends.BuildRedirectURL(config, "foo")
	require.NoError(t, err)
	assert.Equal(t, "127.0.0.1:2369", url.Host)
	assert.Equal(t, "/callback/foo", url.Path)
}
