/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package scrobblerlog_test

import (
	"testing"

	"github.com/spf13/viper"
	"github.com/stretchr/testify/assert"
	"go.uploadedlobster.com/scotty/internal/backends/scrobblerlog"
	"go.uploadedlobster.com/scotty/internal/config"
)

func TestInitConfig(t *testing.T) {
	c := viper.New()
	c.Set("token", "thetoken")
	service := config.NewServiceConfig("test", c)
	backend := scrobblerlog.ScrobblerLogBackend{}
	err := backend.InitConfig(&service)
	assert.NoError(t, err)
}

func TestInitConfigInvalidTimezone(t *testing.T) {
	c := viper.New()
	configuredTimezone := "Invalid/Timezone"
	c.Set("time-zone", configuredTimezone)
	service := config.NewServiceConfig("test", c)
	backend := scrobblerlog.ScrobblerLogBackend{}
	err := backend.InitConfig(&service)
	assert.ErrorContains(t, err, `Invalid time-zone "Invalid/Timezone"`)
}
