/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/

package util_test

import (
	"fmt"
	"testing"

	"github.com/stretchr/testify/assert"
	"go.uploadedlobster.com/scotty/internal/util"
)

func ExampleSum() {
	values := []float64{1.4, 2.2}
	sum := util.Sum(values...)
	fmt.Print(sum)
	// Output: 3.6
}

func TestSumEmpty(t *testing.T) {
	assert.Equal(t, 0, util.Sum([]int{}...))
}

func ExampleAverage() {
	values := []float64{1.4, 2.2, 0.9}
	sum := util.Average(values...)
	fmt.Print(sum)
	// Output: 1.5
}

func TestAverageEmpty(t *testing.T) {
	assert.Equal(t, 0.0, util.Average([]int{}...))
}

func TestAverageInt(t *testing.T) {
	assert := assert.New(t)
	assert.Equal(3.0, util.Average([]int{2, 4, 3}...))
	assert.Equal(1.5, util.Average([]int{2, 1, 1, 2}...))
}
